]> Shamusworld >> Repos - rmac/blobdiff - token.h
Bump version #.
[rmac] / token.h
diff --git a/token.h b/token.h
index 501f1eaaca237be8c6dfec97c230c6bccbba4789..c44989c09f7ca99651f9287432c23828b8e909e7 100644 (file)
--- a/token.h
+++ b/token.h
@@ -62,6 +62,7 @@
 #define CR_MACDEF       'w'                                    // ^^macdef - is macro defined?
 #define CR_TIME         'x'                                    // ^^time - DOS format time
 #define CR_DATE         'y'                                    // ^^date - DOS format date
+#define CR_ABSCOUNT     'z'                                    // ^^abscount - count the number of bytes defined in curent .abs section
 
 // Character Attributes
 #define ILLEG           0                                      // Illegal character (unused)
@@ -111,8 +112,8 @@ IFILE {
 
 #define TOKENSTREAM struct _tokenstream
 TOKENSTREAM {
-       TOKEN token[10];                // 10 ought to be enough for anybody
-       char * string[10];              // same for attached strings
+       TOKEN token[32];                // 32 ought to be enough for anybody (including XiA!)
+       char * string[32];              // same for attached strings
 };
 
 // Information about a macro invocation